@@ -3,6 +3,37 @@ require_relative 'test_helper'
 require File.join Asciidoctor::LIB_DIR, 'asciidoctor/cli'
 
 context 'Invoker' do
+  test 'should allow Options to be passed as first argument of constructor' do
+    opts = Asciidoctor::Cli::Options.new attributes: { 'toc' => '' }, doctype: 'book', eruby: 'erubis'
+    invoker = Asciidoctor::Cli::Invoker.new opts
+    assert_same invoker.options, opts
+  end
+
+  test 'should allow options Hash to be passed as first argument of constructor' do
+    opts = { attributes: { 'toc' => '' }, doctype: 'book', eruby: 'erubis' }
+    invoker = Asciidoctor::Cli::Invoker.new opts
+    resolved_opts = invoker.options
+    assert_equal opts[:attributes], resolved_opts[:attributes]
+    assert_equal 'book', resolved_opts[:attributes]['doctype']
+    assert_equal 'erubis', resolved_opts[:eruby]
+  end
+
+  test 'should parse options from array passed as first argument of constructor' do
+    input_file = fixture_path 'basic.adoc'
+    invoker = Asciidoctor::Cli::Invoker.new ['-s', input_file]
+    resolved_options = invoker.options
+    refute resolved_options[:standalone]
+    assert_equal [input_file], resolved_options[:input_files]
+  end
+
+  test 'should parse options from multiple arguments passed to constructor' do
+    input_file = fixture_path 'basic.adoc'
+    invoker = Asciidoctor::Cli::Invoker.new '-s', input_file
+    resolved_options = invoker.options
+    refute resolved_options[:standalone]
+    assert_equal [input_file], resolved_options[:input_files]
+  end
+
   test 'should parse source and convert to html5 article by default' do
     invoker = nil
     output = nil
