@@ -511,6 +511,25 @@ class ReaderTest < Minitest::Test
         reader = doc.reader
         refute doc.attributes.key?('front-matter')
         assert_equal '---', reader.peek_line
+        assert_equal 1, reader.lineno
+      end
+
+      test 'should not skip front matter if ending delimiter is not found' do
+        input = <<~'EOS'
+        ---
+        title: Document Title
+        tags: [ first, second ]
+        = Document Title
+        Author Name
+
+        preamble
+        EOS
+
+        doc = Asciidoctor::Document.new input, attributes: { 'skip-front-matter' => '' }
+        reader = doc.reader
+        assert_equal '---', reader.peek_line
+        refute doc.attributes.key? 'front-matter'
+        assert_equal 1, reader.lineno
       end
 
       test 'should skip front matter if specified by skip-front-matter attribute' do
@@ -535,6 +554,7 @@ class ReaderTest < Minitest::Test
         reader = doc.reader
         assert_equal '= Document Title', reader.peek_line
         assert_equal front_matter, doc.attributes['front-matter']
+        assert_equal 7, reader.lineno
       end
     end
 
@@ -621,11 +641,21 @@ class ReaderTest < Minitest::Test
     end
 
     context 'Include Directive' do
-      test 'include directive is disabled by default and becomes a link' do
+      test 'should replace include directive with link macro in default safe mode' do
         input = 'include::include-file.adoc[]'
         doc = Asciidoctor::Document.new input
         reader = doc.reader
-        assert_equal 'link:include-file.adoc[]', reader.read_line
+        assert_equal 'link:include-file.adoc[role=include]', reader.read_line
+      end
+
+      test 'should replace include directive with link macro if safe mode allows it, but allow-uri-read is not set' do
+        using_memory_logger do |logger|
+          input = 'include::https://example.org/dist/info.adoc[]'
+          doc = Asciidoctor::Document.new input, safe: :safe
+          reader = doc.reader
+          assert_equal 'link:https://example.org/dist/info.adoc[role=include]', reader.read_line
+          assert_empty logger
+        end
       end
 
       test 'include directive is enabled when safe mode is less than SECURE' do
@@ -683,6 +713,21 @@ class ReaderTest < Minitest::Test
         end
       end
 
+      test 'include directive should not attempt to resolve target as remote if allow-uri-read is set and URL is not on first line' do
+        using_memory_logger do |logger|
+          input = <<~'EOS'
+          :target: not-a-file.adoc + \
+          http://example.org/team.adoc
+
+          include::{target}[]
+          EOS
+          doc = Asciidoctor.load input, safe: :safe, base_dir: fixturedir
+          lines = doc.blocks[0].lines
+          assert_equal [%(Unresolved directive in <stdin> - include::not-a-file.adoc +\nhttp://example.org/team.adoc[])], lines
+          assert_message logger, :ERROR, %(<stdin>: line 4: include file not found: #{fixture_path 'not-a-file.adoc'} +\nhttp://example.org/team.adoc), Hash
+        end
+      end
+
       test 'include directive should resolve file relative to current include' do
         input = 'include::fixtures/parent-include.adoc[]'
         pseudo_docfile = File.join DIRNAME, 'main.adoc'
